import {
  select,
  geoCentroid,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event,
  scaleOrdinal,
  schemeSpectral,
  scaleSqrt,
  max,
  format
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { sizeLegend } from './sizeLegend';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const radiusValue = d=> 10*d.properties['2030'];

const colorLegendG = svg.append('g')
    .attr('transform', `translate(40,310)`);

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

const populationFormat=format(',');
loadAndProcessData().then(countries => {
  
  const sizeScale=scaleSqrt();
  sizeScale
  .domain([0,max(countries.features,d=> 10*d.properties['2030'])])
  .range([0,33]);
 console.log(max(countries.features,d=> d.properties['2030']));
  
  g.selectAll('path').data(countries.featuresWithPopulation)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
  
      .attr('fill', d => d.properties['2030'] ? '#e8e8e8' : '#fecccc')
    .append('title')
      .text(d => [isNaN(radiusValue(d))? 'Missing Data':
    d.properties['Region, subregion, country or area *'],
    populationFormat(radiusValue(d))].join(': '));
  
  countries.featuresWithPopulation.forEach(d => {
  d.properties.projected=projection(geoCentroid(d));
   
  });
  
  const circles= g.selectAll('circle')
    .data(countries.featuresWithPopulation);
  circles
    .enter().append('circle')
   // .transition().duration(8000)
      .attr('class', 'country-circle')
//    .attr('cx', d =>  d.properties.projected[0])
//    .attr('cy', d => d.properties.projected[1])
  		.attr('r', 0)
 .merge(circles)   
 .transition().duration(2000)
  		.attr('cx', d =>  d.properties.projected[0])
   .attr('cy', d => d.properties.projected[1])
    .attr('r', d=> sizeScale(100*d.properties['2020']))
  ;
  
  for(let i=0;i<11;i++){
 const circles= g.selectAll('circle')
    .data(countries.featuresWithPopulation);
  circles
  //  .enter().append('circle')
   // .transition().duration(8000)
      .attr('class', 'country-circle')
    .attr('cx', d =>  d.properties.projected[0])
    .attr('cy', d => d.properties.projected[1])
  		.attr('r', d=> sizeScale((1)*d.properties['2020']))   
 .merge(circles)   
 .transition().duration(5000)
  		.attr('cx', d =>  d.properties.projected[0])
    .attr('cy', d => d.properties.projected[1])
    .attr('r', d=> sizeScale((1+i*Math.pow(-1,i))*d.properties['2020']))
    .transition().duration(5000)
    .attr('r', d=> sizeScale((-8+i)*d.properties['2020']))
    ;
    };
  
 //d3.selectAll('circle').transition().style("color","red").duration(10000);
 /*for(let i=0;i<11;i++){
  const circles=g.selectAll('circle')
 .data(countries.featuresWithPopulation)
   circles
  .enter().append('circle')
   .merge(circles)
    .transition().duration(2000)
    .attr('cx', d =>  d.properties.projected[0])
    .attr('cy', d => d.properties.projected[1])
    .attr('r', d=> sizeScale((1+i)*d.properties['2030']));
    
  };*/
  g.append('g')
    .attr('transform', `translate(55,215)`)
    .call(sizeLegend, {
      sizeScale,
      spacing: 45,
      textOffset: 10,
      numTicks: 5,
    	tickFormat:populationFormat
    })
  .append('text')
  .attr('class','clap')
  .text('Population')
  .attr('y',-45)
  .attr('x',-30);
});
